pub struct OldPosition(/* private fields */);Expand description
The value of Position from the end of the previous tick.
NOTE: You should not modify this component after the entity is spawned.
Implementations
Methods from Deref<Target = DVec3>
pub const ZERO: DVec3
pub const ONE: DVec3
pub const NEG_ONE: DVec3
pub const MIN: DVec3
pub const MAX: DVec3
pub const NAN: DVec3
pub const INFINITY: DVec3
pub const NEG_INFINITY: DVec3
pub const X: DVec3
pub const Y: DVec3
pub const Z: DVec3
pub const NEG_X: DVec3
pub const NEG_Y: DVec3
pub const NEG_Z: DVec3
pub const AXES: [DVec3; 3]
Sourcepub fn move_towards(&self, rhs: DVec3, d: f64) -> DVec3
pub fn move_towards(&self, rhs: DVec3, d: f64) -> DVec3
Moves towards rhs based on the value d.
When d is 0.0, the result will be equal to self. When d is equal to
self.distance(rhs), the result will be equal to rhs. Will not go past rhs.
Sourcepub fn any_orthogonal_vector(&self) -> DVec3
pub fn any_orthogonal_vector(&self) -> DVec3
Returns some vector that is orthogonal to the given one.
The input vector must be finite and non-zero.
The output vector is not necessarily unit length. For that use
Self::any_orthonormal_vector() instead.
Sourcepub fn any_orthonormal_vector(&self) -> DVec3
pub fn any_orthonormal_vector(&self) -> DVec3
Returns any unit vector that is orthogonal to the given one.
The input vector must be unit length.
Panics
Will panic if self is not normalized when glam_assert is enabled.
Sourcepub fn any_orthonormal_pair(&self) -> (DVec3, DVec3)
pub fn any_orthonormal_pair(&self) -> (DVec3, DVec3)
Given a unit vector return two other vectors that together form an orthonormal basis. That is, all three vectors are orthogonal to each other and are normalized.
Panics
Will panic if self is not normalized when glam_assert is enabled.
Sourcepub fn as_i16vec3(&self) -> I16Vec3
pub fn as_i16vec3(&self) -> I16Vec3
Casts all elements of self to i16.
Sourcepub fn as_u16vec3(&self) -> U16Vec3
pub fn as_u16vec3(&self) -> U16Vec3
Casts all elements of self to u16.
Sourcepub fn as_i64vec3(&self) -> I64Vec3
pub fn as_i64vec3(&self) -> I64Vec3
Casts all elements of self to i64.
Sourcepub fn as_u64vec3(&self) -> U64Vec3
pub fn as_u64vec3(&self) -> U64Vec3
Casts all elements of self to u64.